
document: https://www.yuque.com/xlpr/pyxllib

pypi: https://pypi.org/project/pyxllib/

推荐使用0.0.13以上的版本，并且考虑大部分人把pip默认都改成清华源了，有时候版本更新还没有第一时间同步到清华源，所以加了一个pypi官方的--extra-index-url作为备用。

```
pip install pyxllib>=0.0.13 --extra-index-url=https://pypi.python.org/simple/
```
